#include <QtCore>
#include "packagedb.h"
#include "globals.h"


void printUsage()
{
    QTextStream out(stderr);
    out << "Usage: mib-report [--update] [--report table mode] [--search package] [--version]" << endl << endl;
    out << "--update            Download packages lists from reference repositories" << endl;
    out << "--report            Print HTML report for seleced table and mode to stdout" << endl;
    out << "  tables:" << endl;
    out << "    mib             Report for MIB repositories" << endl;
    out << "    mga-mdv         Report for MGA VS MDV repositories" << endl;
    out << "    mdv-mga         Report for MDV VS MGA repositories" << endl;
    out << "  modes:" << endl;
    out << "    all             Report for all packages" << endl;
    out << "    exclusives      Report for exclusive packages" << endl;
    out << "    updates         Report for packages with updates available" << endl;
    out << "--search package    Search for package in reference repositories then" << endl;
    out << "                    print versions and URLs to stdout" << endl << endl;
    out << "Usage examples:" << endl;
    out << "mib-report --report mib updates > table.html    Print HTML report to table.html file" << endl;
    out << "mib-report --report mga-mdv all > table.html    Print HTML report to table.html file" << endl;
    out << "mib-report --search mc                          Search for package mc and display results" << endl;
}

int main(int argc, char *argv[])
{
    QCoreApplication a(argc, argv);
    QTextStream out(stderr);
    QStringList opts;
    for (int j=0; j < argc; j++)
    {
        opts << argv[j];
    }

    if (opts.contains("--help") || opts.count() < 2)
    {
        printUsage();
        a.quit();
        return 0;
    }

    if (opts.at(1) == "--version")
    {
        if (opts.count() > 2)
        {
            printUsage();
        }
        else
        {
            out << "mib-report v. " << VERSION << endl;
            out << "Copyright (C) 2011-2012 Andrey Bondrov, Mandriva International Backports" << endl;
            out << "http://mib.pianetalinux.org" << endl;
            out << "Released under GPLv2 license" << endl;
        }
        a.quit();
        return 0;
    }

    if (opts.at(1) == "--update")
    {
        if (opts.count() > 2)
        {
            printUsage();
        }
        else
        {
            PackageDB db;
            db.updateLists();
        }
        a.quit();
        return 0;
    }

    if (opts.at(1) == "--report")
    {
        if (opts.count() != 4)
        {
            printUsage();
        }
        else if (!((opts.at(2) == "mib") || (opts.at(2) == "mga-mdv") || (opts.at(2) == "mdv-mga")) || !((opts.at(3) == "all") || (opts.at(3) == "exclusives") || (opts.at(3) == "updates")))
        {
            printUsage();
        }
        else
        {
            PackageDB db;
            db.initDB();
            if (db.statusOK)
            {
                if ((opts.at(2) == "mib") && (opts.at(3) == "all"))
                    db.generateHTMLTableMIB(REPORT_ALL);
                if ((opts.at(2) == "mib") && (opts.at(3) == "exclusives"))
                    db.generateHTMLTableMIB(REPORT_EXCLUSIVES);
                if ((opts.at(2) == "mib") && (opts.at(3) == "updates"))
                    db.generateHTMLTableMIB(REPORT_UPDATES);
                if ((opts.at(2) == "mga-mdv") && (opts.at(3) == "all"))
                    db.generateHTMLTableMGAvsMDV(REPORT_ALL);
                if ((opts.at(2) == "mga-mdv") && (opts.at(3) == "exclusives"))
                    db.generateHTMLTableMGAvsMDV(REPORT_EXCLUSIVES);
                if ((opts.at(2) == "mga-mdv") && (opts.at(3) == "updates"))
                    db.generateHTMLTableMGAvsMDV(REPORT_UPDATES);
                if ((opts.at(2) == "mdv-mga") && (opts.at(3) == "all"))
                    db.generateHTMLTableMDVvsMGA(REPORT_ALL);
                if ((opts.at(2) == "mdv-mga") && (opts.at(3) == "exclusives"))
                    db.generateHTMLTableMDVvsMGA(REPORT_EXCLUSIVES);
                if ((opts.at(2) == "mdv-mga") && (opts.at(3) == "updates"))
                    db.generateHTMLTableMDVvsMGA(REPORT_UPDATES);
            }
            else
            {
                if (db.statusString.contains("Error opening file"))
                    out << "Error loading package database: run with --update option first" << endl;
                else
                    out << "Error loading package database: " << db.statusString << endl;
            }
        }
        a.quit();
        return 0;
    }

    if (opts.at(1) == "--search")
    {
        if (opts.count() != 3)
        {
            printUsage();
        }
        else
        {
            out << "Searching for package " << opts.at(2) << "..." << endl;
            PackageDB db;
            db.initDB();
            if (db.statusOK)
                db.search(opts.at(2));
            else
            {
                if (db.statusString.contains("Error opening file"))
                    out << "Error loading package database: run with --update option first" << endl;
                else
                    out << "Error loading package database: " << db.statusString << endl;
            }
        }
        a.quit();
        return 0;
    }

    printUsage();
    a.quit();
    return 0;
}
